@@ -1,9 +1,9 @@
 mod algorithm;
-mod hyperparameters;
+mod hyperparams;
 mod iter;
 mod tikz;
 
 pub use algorithm::*;
-pub use hyperparameters::*;
+pub use hyperparams::*;
 pub use iter::*;
 pub use tikz::*;
